# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_sql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61zure/azure_microsoft_sql.proto\x12\x1foak9.tython.azure.microsoft_sql\x1a\x13shared/shared.proto\"\xa9\x02\n\rMicrosoft_Sql\x12\x46\n\x0einstance_pools\x18\x01 \x03(\x0b\x32..oak9.tython.azure.microsoft_sql.InstancePools\x12l\n\"locations_instance_failover_groups\x18\x02 \x03(\x0b\x32@.oak9.tython.azure.microsoft_sql.LocationsInstanceFailoverGroups\x12\x62\n\x1dlocations_server_trust_groups\x18\x03 \x03(\x0b\x32;.oak9.tython.azure.microsoft_sql.LocationsServerTrustGroups\"\xbd\x01\n\x1aLocationsServerTrustGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\rgroup_members\x18\x03 \x03(\x0b\x32+.oak9.tython.azure.microsoft_sql.ServerInfo\x12\x14\n\x0ctrust_scopes\x18\x04 \x03(\t\"\x1f\n\nServerInfo\x12\x11\n\tserver_id\x18\x01 \x01(\t\"\xd9\x03\n\x1fLocationsInstanceFailoverGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x16managed_instance_pairs\x18\x03 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_sql.ManagedInstancePairInfo\x12K\n\x0fpartner_regions\x18\x04 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_sql.PartnerRegionInfo\x12\x62\n\x12read_only_endpoint\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_sql.InstanceFailoverGroupReadOnlyEndpoint\x12\x64\n\x13read_write_endpoint\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_sql.InstanceFailoverGroupReadWriteEndpoint\"w\n&InstanceFailoverGroupReadWriteEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\x12\x34\n,failover_with_data_loss_grace_period_minutes\x18\x02 \x01(\x05\"@\n%InstanceFailoverGroupReadOnlyEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\"%\n\x11PartnerRegionInfo\x12\x10\n\x08location\x18\x01 \x01(\t\"c\n\x17ManagedInstancePairInfo\x12#\n\x1bpartner_managed_instance_id\x18\x01 \x01(\t\x12#\n\x1bprimary_managed_instance_id\x18\x02 \x01(\t\"\xca\x02\n\rInstancePools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0clicense_type\x18\x04 \x01(\t\x12\x11\n\tsubnet_id\x18\x05 \x01(\t\x12\x0f\n\x07v_cores\x18\x06 \x01(\x05\x12\x31\n\x03sku\x18\x07 \x01(\x0b\x32$.oak9.tython.azure.microsoft_sql.Sku\x12\x46\n\x04tags\x18\x08 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_sql.InstancePools.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_sql_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INSTANCEPOOLS_TAGSENTRY._options = None
  _INSTANCEPOOLS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_SQL._serialized_start=90
  _MICROSOFT_SQL._serialized_end=387
  _LOCATIONSSERVERTRUSTGROUPS._serialized_start=390
  _LOCATIONSSERVERTRUSTGROUPS._serialized_end=579
  _SERVERINFO._serialized_start=581
  _SERVERINFO._serialized_end=612
  _LOCATIONSINSTANCEFAILOVERGROUPS._serialized_start=615
  _LOCATIONSINSTANCEFAILOVERGROUPS._serialized_end=1088
  _INSTANCEFAILOVERGROUPREADWRITEENDPOINT._serialized_start=1090
  _INSTANCEFAILOVERGROUPREADWRITEENDPOINT._serialized_end=1209
  _INSTANCEFAILOVERGROUPREADONLYENDPOINT._serialized_start=1211
  _INSTANCEFAILOVERGROUPREADONLYENDPOINT._serialized_end=1275
  _PARTNERREGIONINFO._serialized_start=1277
  _PARTNERREGIONINFO._serialized_end=1314
  _MANAGEDINSTANCEPAIRINFO._serialized_start=1316
  _MANAGEDINSTANCEPAIRINFO._serialized_end=1415
  _INSTANCEPOOLS._serialized_start=1418
  _INSTANCEPOOLS._serialized_end=1748
  _INSTANCEPOOLS_TAGSENTRY._serialized_start=1705
  _INSTANCEPOOLS_TAGSENTRY._serialized_end=1748
  _SKU._serialized_start=1750
  _SKU._serialized_end=1831
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Connection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONNECTION_NAME_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    HOST_ARN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    connection_name: builtins.str
    provider_type: builtins.str
    host_arn: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        connection_name: builtins.str = ...,
        provider_type: builtins.str = ...,
        host_arn: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_name", b"connection_name", "host_arn", b"host_arn", "provider_type", b"provider_type", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Connection = Connection

@typing_extensions.final
class CodeStarConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connection]: ...
    def __init__(
        self,
        *,
        connection: collections.abc.Iterable[global___Connection] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> None: ...

global___CodeStarConnections = CodeStarConnections



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_acmpca.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_acmpca.proto\x12\x16oak9.tython.aws.acmpca\x1a\x13shared/shared.proto\"]\n\x13\x43\x65rtificateValidity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\x05\"\xfe\x01\n\x0b\x43\x65rtificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12#\n\x1b\x63\x65rtificate_signing_request\x18\x03 \x01(\t\x12\x19\n\x11signing_algorithm\x18\x04 \x01(\t\x12\x14\n\x0ctemplate_arn\x18\x05 \x01(\t\x12=\n\x08validity\x18\x06 \x01(\x0b\x32+.oak9.tython.aws.acmpca.CertificateValidity\"\xf1\x01\n\x06\x41\x43MPCA\x12\x38\n\x0b\x63\x65rtificate\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.acmpca.Certificate\x12K\n\x15\x63\x65rtificate_authority\x18\x02 \x03(\x0b\x32,.oak9.tython.aws.acmpca.CertificateAuthority\x12`\n certificate_authority_activation\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.acmpca.CertificateAuthorityActivation\"\x84\x03\n\x1b\x43\x65rtificateAuthoritySubject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x14\n\x0corganization\x18\x03 \x01(\t\x12\x1b\n\x13organizational_unit\x18\x04 \x01(\t\x12$\n\x1c\x64istinguished_name_qualifier\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x07 \x01(\t\x12\x15\n\rserial_number\x18\x08 \x01(\t\x12\x10\n\x08locality\x18\t \x01(\t\x12\r\n\x05title\x18\n \x01(\t\x12\x0f\n\x07surname\x18\x0b \x01(\t\x12\x12\n\ngiven_name\x18\x0c \x01(\t\x12\x10\n\x08initials\x18\r \x01(\t\x12\x11\n\tpseudonym\x18\x0e \x01(\t\x12\x1c\n\x14generation_qualifier\x18\x0f \x01(\t\"\xba\x01\n$CertificateAuthorityCrlConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x1a\n\x12\x65xpiration_in_days\x18\x03 \x01(\x05\x12\x14\n\x0c\x63ustom_cname\x18\x04 \x01(\t\x12\x16\n\x0es3_bucket_name\x18\x05 \x01(\t\"\xbf\x01\n+CertificateAuthorityRevocationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x11\x63rl_configuration\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.acmpca.CertificateAuthorityCrlConfiguration\"\xaf\x03\n\x14\x43\x65rtificateAuthority\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x15\n\rkey_algorithm\x18\x03 \x01(\t\x12\x19\n\x11signing_algorithm\x18\x04 \x01(\t\x12\x44\n\x07subject\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.acmpca.CertificateAuthoritySubject\x12\x65\n\x18revocation_configuration\x18\x06 \x01(\x0b\x32\x43.oak9.tython.aws.acmpca.CertificateAuthorityRevocationConfiguration\x12\x44\n\x04tags\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.acmpca.CertificateAuthority.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x1e\x43\x65rtificateAuthorityActivation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63\x65rtificate_authority_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x03 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_acmpca_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CERTIFICATEAUTHORITY_TAGSENTRY._options = None
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_options = b'8\001'
  _CERTIFICATEVALIDITY._serialized_start=69
  _CERTIFICATEVALIDITY._serialized_end=162
  _CERTIFICATE._serialized_start=165
  _CERTIFICATE._serialized_end=419
  _ACMPCA._serialized_start=422
  _ACMPCA._serialized_end=663
  _CERTIFICATEAUTHORITYSUBJECT._serialized_start=666
  _CERTIFICATEAUTHORITYSUBJECT._serialized_end=1054
  _CERTIFICATEAUTHORITYCRLCONFIGURATION._serialized_start=1057
  _CERTIFICATEAUTHORITYCRLCONFIGURATION._serialized_end=1243
  _CERTIFICATEAUTHORITYREVOCATIONCONFIGURATION._serialized_start=1246
  _CERTIFICATEAUTHORITYREVOCATIONCONFIGURATION._serialized_end=1437
  _CERTIFICATEAUTHORITY._serialized_start=1440
  _CERTIFICATEAUTHORITY._serialized_end=1871
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_start=1828
  _CERTIFICATEAUTHORITY_TAGSENTRY._serialized_end=1871
  _CERTIFICATEAUTHORITYACTIVATION._serialized_start=1874
  _CERTIFICATEAUTHORITYACTIVATION._serialized_end=2062
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeAttachedDiskXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeAttachedDiskXTimeouts = ComputeAttachedDiskXTimeouts

@typing_extensions.final
class ComputeAttachedDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DISK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    disk: builtins.str
    id: builtins.str
    instance: builtins.str
    mode: builtins.str
    project: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeAttachedDiskXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        disk: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        mode: builtins.str = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeAttachedDiskXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "disk", b"disk", "id", b"id", "instance", b"instance", "mode", b"mode", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeAttachedDisk = ComputeAttachedDisk



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_appsync.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_appsync.proto\x12\x17oak9.tython.aws.appsync\x1a\x13shared/shared.proto\"\xd4\x01\n\x08\x41piCache\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\"\n\x1atransit_encryption_enabled\x18\x03 \x01(\x08\x12\"\n\x1a\x61t_rest_encryption_enabled\x18\x04 \x01(\x08\x12\x0e\n\x06\x61pi_id\x18\x05 \x01(\t\x12\x1c\n\x14\x61pi_caching_behavior\x18\x06 \x01(\t\x12\x0b\n\x03ttl\x18\x07 \x01(\x01\"\xad\x04\n\x07\x41ppSync\x12\x34\n\tapi_cache\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.appsync.ApiCache\x12\x30\n\x07\x61pi_key\x18\x02 \x03(\x0b\x32\x1f.oak9.tython.aws.appsync.ApiKey\x12\x38\n\x0b\x64\x61ta_source\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.appsync.DataSource\x12N\n\x16\x66unction_configuration\x18\x04 \x03(\x0b\x32..oak9.tython.aws.appsync.FunctionConfiguration\x12:\n\rgraph_q_l_api\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.appsync.GraphQLApi\x12@\n\x10graph_q_l_schema\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.appsync.GraphQLSchema\x12\x33\n\x08resolver\x18\x07 \x03(\x0b\x32!.oak9.tython.aws.appsync.Resolver\x12}\n0graph_q_l_api_additional_authentication_provider\x18\x08 \x03(\x0b\x32\x43.oak9.tython.aws.appsync.GraphQLApiAdditionalAuthenticationProvider\"w\n\x06\x41piKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x03 \x01(\x01\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"\x87\x01\n\x16\x44\x61taSourceAwsIamConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0esigning_region\x18\x02 \x01(\t\x12\x1c\n\x14signing_service_name\x18\x03 \x01(\t\"\xbd\x01\n\x1d\x44\x61taSourceAuthorizationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0e\x61ws_iam_config\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.appsync.DataSourceAwsIamConfig\x12\x1a\n\x12\x61uthorization_type\x18\x03 \x01(\t\"\xb7\x01\n\x14\x44\x61taSourceHttpConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12T\n\x14\x61uthorization_config\x18\x03 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.DataSourceAuthorizationConfig\"\xd2\x01\n\x1f\x44\x61taSourceRdsHttpEndpointConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naws_region\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x15\n\rdatabase_name\x18\x04 \x01(\t\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x05 \x01(\t\x12\x1c\n\x14\x61ws_secret_store_arn\x18\x06 \x01(\t\"\xe2\x01\n\"DataSourceRelationalDatabaseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x18rds_http_endpoint_config\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.appsync.DataSourceRdsHttpEndpointConfig\x12\'\n\x1frelational_database_source_type\x18\x03 \x01(\t\"n\n\x16\x44\x61taSourceLambdaConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13lambda_function_arn\x18\x02 \x01(\t\"\xa9\x01\n\x19\x44\x61taSourceDeltaSyncConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x62\x61se_table_ttl\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65lta_sync_table_ttl\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65lta_sync_table_name\x18\x04 \x01(\t\"\xfd\x01\n\x18\x44\x61taSourceDynamoDBConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x12\n\naws_region\x18\x03 \x01(\t\x12\x11\n\tversioned\x18\x04 \x01(\x08\x12M\n\x11\x64\x65lta_sync_config\x18\x05 \x01(\x0b\x32\x32.oak9.tython.aws.appsync.DataSourceDeltaSyncConfig\x12\x1e\n\x16use_caller_credentials\x18\x06 \x01(\x08\"~\n\x1d\x44\x61taSourceElasticsearchConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\naws_region\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\"\xb0\x04\n\nDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10service_role_arn\x18\x04 \x01(\t\x12\x42\n\x0bhttp_config\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.appsync.DataSourceHttpConfig\x12_\n\x1arelational_database_config\x18\x06 \x01(\x0b\x32;.oak9.tython.aws.appsync.DataSourceRelationalDatabaseConfig\x12\x46\n\rlambda_config\x18\x07 \x01(\x0b\x32/.oak9.tython.aws.appsync.DataSourceLambdaConfig\x12\x0e\n\x06\x61pi_id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12K\n\x10\x64ynamo_db_config\x18\n \x01(\x0b\x32\x31.oak9.tython.aws.appsync.DataSourceDynamoDBConfig\x12T\n\x14\x65lasticsearch_config\x18\x0b \x01(\x0b\x32\x36.oak9.tython.aws.appsync.DataSourceElasticsearchConfig\"\xd9\x02\n\x15\x46unctionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n%response_mapping_template_s3_location\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x18\n\x10\x64\x61ta_source_name\x18\x04 \x01(\t\x12 \n\x18request_mapping_template\x18\x05 \x01(\t\x12!\n\x19response_mapping_template\x18\x06 \x01(\t\x12\x18\n\x10\x66unction_version\x18\x07 \x01(\t\x12,\n$request_mapping_template_s3_location\x18\x08 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\"\x9e\x01\n\x1dGraphQLApiOpenIDConnectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x10\n\x08\x61uth_ttl\x18\x04 \x01(\x01\x12\x0f\n\x07iat_ttl\x18\x05 \x01(\x01\"\xb2\x01\n\x18GraphQLApiUserPoolConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pp_id_client_regex\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x12\n\naws_region\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x05 \x01(\t\"I\n\x0eGraphQLApiTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x13GraphQLApiLogConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63loud_watch_logs_role_arn\x18\x02 \x01(\t\x12\x1f\n\x17\x65xclude_verbose_content\x18\x03 \x01(\x08\x12\x17\n\x0f\x66ield_log_level\x18\x04 \x01(\t\"f\n+GraphQLApiAdditionalAuthenticationProviders\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x97\x04\n\nGraphQLApi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x16open_id_connect_config\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.GraphQLApiOpenIDConnectConfig\x12\x14\n\x0cxray_enabled\x18\x03 \x01(\x08\x12K\n\x10user_pool_config\x18\x04 \x01(\x0b\x32\x31.oak9.tython.aws.appsync.GraphQLApiUserPoolConfig\x12\x35\n\x04tags\x18\x05 \x01(\x0b\x32\'.oak9.tython.aws.appsync.GraphQLApiTags\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13\x61uthentication_type\x18\x07 \x01(\t\x12@\n\nlog_config\x18\x08 \x01(\x0b\x32,.oak9.tython.aws.appsync.GraphQLApiLogConfig\x12q\n#additional_authentication_providers\x18\t \x01(\x0b\x32\x44.oak9.tython.aws.appsync.GraphQLApiAdditionalAuthenticationProviders\"\x8c\x01\n\rGraphQLSchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65\x66inition_s3_location\x18\x03 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x04 \x01(\t\"d\n\x16ResolverPipelineConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfunctions\x18\x02 \x03(\t\"s\n\x15ResolverCachingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63\x61\x63hing_keys\x18\x02 \x03(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\x01\"\x83\x01\n#ResolverLambdaConflictHandlerConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1blambda_conflict_handler_arn\x18\x02 \x01(\t\"\xe9\x01\n\x12ResolverSyncConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63onflict_handler\x18\x02 \x01(\t\x12\x1a\n\x12\x63onflict_detection\x18\x03 \x01(\t\x12\x64\n\x1elambda_conflict_handler_config\x18\x04 \x01(\x0b\x32<.oak9.tython.aws.appsync.ResolverLambdaConflictHandlerConfig\"\x98\x04\n\x08Resolver\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12-\n%response_mapping_template_s3_location\x18\x02 \x01(\t\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12H\n\x0fpipeline_config\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.appsync.ResolverPipelineConfig\x12\x18\n\x10\x64\x61ta_source_name\x18\x05 \x01(\t\x12 \n\x18request_mapping_template\x18\x06 \x01(\t\x12!\n\x19response_mapping_template\x18\x07 \x01(\t\x12\x0c\n\x04kind\x18\x08 \x01(\t\x12\x46\n\x0e\x63\x61\x63hing_config\x18\t \x01(\x0b\x32..oak9.tython.aws.appsync.ResolverCachingConfig\x12@\n\x0bsync_config\x18\n \x01(\x0b\x32+.oak9.tython.aws.appsync.ResolverSyncConfig\x12,\n$request_mapping_template_s3_location\x18\x0b \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x0c \x01(\t\x12\x12\n\nfield_name\x18\r \x01(\t\"\xa1\x01\n\x1fGraphQLApiCognitoUserPoolConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pp_id_client_regex\x18\x02 \x01(\t\x12\x14\n\x0cuser_pool_id\x18\x03 \x01(\t\x12\x12\n\naws_region\x18\x04 \x01(\t\"\xae\x02\n*GraphQLApiAdditionalAuthenticationProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x16open_id_connect_config\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.appsync.GraphQLApiOpenIDConnectConfig\x12R\n\x10user_pool_config\x18\x03 \x01(\x0b\x32\x38.oak9.tython.aws.appsync.GraphQLApiCognitoUserPoolConfig\x12\x1b\n\x13\x61uthentication_type\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_appsync_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APICACHE._serialized_start=72
  _APICACHE._serialized_end=284
  _APPSYNC._serialized_start=287
  _APPSYNC._serialized_end=844
  _APIKEY._serialized_start=846
  _APIKEY._serialized_end=965
  _DATASOURCEAWSIAMCONFIG._serialized_start=968
  _DATASOURCEAWSIAMCONFIG._serialized_end=1103
  _DATASOURCEAUTHORIZATIONCONFIG._serialized_start=1106
  _DATASOURCEAUTHORIZATIONCONFIG._serialized_end=1295
  _DATASOURCEHTTPCONFIG._serialized_start=1298
  _DATASOURCEHTTPCONFIG._serialized_end=1481
  _DATASOURCERDSHTTPENDPOINTCONFIG._serialized_start=1484
  _DATASOURCERDSHTTPENDPOINTCONFIG._serialized_end=1694
  _DATASOURCERELATIONALDATABASECONFIG._serialized_start=1697
  _DATASOURCERELATIONALDATABASECONFIG._serialized_end=1923
  _DATASOURCELAMBDACONFIG._serialized_start=1925
  _DATASOURCELAMBDACONFIG._serialized_end=2035
  _DATASOURCEDELTASYNCCONFIG._serialized_start=2038
  _DATASOURCEDELTASYNCCONFIG._serialized_end=2207
  _DATASOURCEDYNAMODBCONFIG._serialized_start=2210
  _DATASOURCEDYNAMODBCONFIG._serialized_end=2463
  _DATASOURCEELASTICSEARCHCONFIG._serialized_start=2465
  _DATASOURCEELASTICSEARCHCONFIG._serialized_end=2591
  _DATASOURCE._serialized_start=2594
  _DATASOURCE._serialized_end=3154
  _FUNCTIONCONFIGURATION._serialized_start=3157
  _FUNCTIONCONFIGURATION._serialized_end=3502
  _GRAPHQLAPIOPENIDCONNECTCONFIG._serialized_start=3505
  _GRAPHQLAPIOPENIDCONNECTCONFIG._serialized_end=3663
  _GRAPHQLAPIUSERPOOLCONFIG._serialized_start=3666
  _GRAPHQLAPIUSERPOOLCONFIG._serialized_end=3844
  _GRAPHQLAPITAGS._serialized_start=3846
  _GRAPHQLAPITAGS._serialized_end=3919
  _GRAPHQLAPILOGCONFIG._serialized_start=3922
  _GRAPHQLAPILOGCONFIG._serialized_end=4093
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDERS._serialized_start=4095
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDERS._serialized_end=4197
  _GRAPHQLAPI._serialized_start=4200
  _GRAPHQLAPI._serialized_end=4735
  _GRAPHQLSCHEMA._serialized_start=4738
  _GRAPHQLSCHEMA._serialized_end=4878
  _RESOLVERPIPELINECONFIG._serialized_start=4880
  _RESOLVERPIPELINECONFIG._serialized_end=4980
  _RESOLVERCACHINGCONFIG._serialized_start=4982
  _RESOLVERCACHINGCONFIG._serialized_end=5097
  _RESOLVERLAMBDACONFLICTHANDLERCONFIG._serialized_start=5100
  _RESOLVERLAMBDACONFLICTHANDLERCONFIG._serialized_end=5231
  _RESOLVERSYNCCONFIG._serialized_start=5234
  _RESOLVERSYNCCONFIG._serialized_end=5467
  _RESOLVER._serialized_start=5470
  _RESOLVER._serialized_end=6006
  _GRAPHQLAPICOGNITOUSERPOOLCONFIG._serialized_start=6009
  _GRAPHQLAPICOGNITOUSERPOOLCONFIG._serialized_end=6170
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDER._serialized_start=6173
  _GRAPHQLAPIADDITIONALAUTHENTICATIONPROVIDER._serialized_end=6475
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_sql_managedinstances.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0azure/azure_microsoft_sql_managedinstances.proto\x12\x30oak9.tython.azure.microsoft_sql_managedinstances\x1a\x13shared/shared.proto\"\x92\x01\n\x1eMicrosoft_Sql_ManagedInstances\x12p\n\x1bmanaged_instances_databases\x18\x01 \x03(\x0b\x32K.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabases\"\xd4\x02\n(ManagedInstancesVulnerabilityAssessments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12z\n\x0frecurring_scans\x18\x03 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_sql_managedinstances.VulnerabilityAssessmentRecurringScansProperties\x12\"\n\x1astorage_account_access_key\x18\x04 \x01(\t\x12\x1e\n\x16storage_container_path\x18\x05 \x01(\t\x12!\n\x19storage_container_sas_key\x18\x06 \x01(\t\"p\n\x18ManagedInstancesSqlAgent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\"\x85\x01\n\'ManagedInstancesServerTrustCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpublic_blob\x18\x03 \x01(\t\"\xa3\x02\n%ManagedInstancesSecurityAlertPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64isabled_alerts\x18\x03 \x03(\t\x12\x1c\n\x14\x65mail_account_admins\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mail_addresses\x18\x05 \x03(\t\x12\x16\n\x0eretention_days\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x08 \x01(\t\x12\x18\n\x10storage_endpoint\x18\t \x01(\t\"\xab\x01\nJManagedInstancesRestorableDroppedDatabasesBackupShortTermRetentionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eretention_days\x18\x03 \x01(\x05\"\x83\x03\n*ManagedInstancesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12r\n\x10private_endpoint\x18\x03 \x01(\x0b\x32X.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancePrivateEndpointProperty\x12\x99\x01\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32j.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancePrivateLinkServiceConnectionStateProperty\"_\n8ManagedInstancePrivateLinkServiceConnectionStateProperty\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"4\n&ManagedInstancePrivateEndpointProperty\x12\n\n\x02id\x18\x01 \x01(\t\"\x83\x01\n\x14ManagedInstancesKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"\xbd\x01\n#ManagedInstancesEncryptionProtector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15\x61uto_rotation_enabled\x18\x03 \x01(\x08\x12\x17\n\x0fserver_key_name\x18\x04 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x05 \x01(\t\"\x96\x02\n-ManagedInstancesDistributedAvailabilityGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x1fprimary_availability_group_name\x18\x03 \x01(\t\x12\x18\n\x10replication_mode\x18\x04 \x01(\t\x12)\n!secondary_availability_group_name\x18\x05 \x01(\t\x12\x17\n\x0fsource_endpoint\x18\x06 \x01(\t\x12\x17\n\x0ftarget_database\x18\x07 \x01(\t\"\x85\x02\n?ManagedInstancesDatabasesVulnerabilityAssessmentsRulesBaselines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12{\n\x10\x62\x61seline_results\x18\x03 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_sql_managedinstances.DatabaseVulnerabilityAssessmentRuleBaselineItem\"A\n/DatabaseVulnerabilityAssessmentRuleBaselineItem\x12\x0e\n\x06result\x18\x01 \x03(\t\"\xdd\x02\n1ManagedInstancesDatabasesVulnerabilityAssessments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12z\n\x0frecurring_scans\x18\x03 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_sql_managedinstances.VulnerabilityAssessmentRecurringScansProperties\x12\"\n\x1astorage_account_access_key\x18\x04 \x01(\t\x12\x1e\n\x16storage_container_path\x18\x05 \x01(\t\x12!\n\x19storage_container_sas_key\x18\x06 \x01(\t\"x\n/VulnerabilityAssessmentRecurringScansProperties\x12\x0e\n\x06\x65mails\x18\x01 \x03(\t\x12!\n\x19\x65mail_subscription_admins\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"\x8a\x01\n2ManagedInstancesDatabasesTransparentDataEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\"\xac\x02\n.ManagedInstancesDatabasesSecurityAlertPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64isabled_alerts\x18\x03 \x03(\t\x12\x1c\n\x14\x65mail_account_admins\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mail_addresses\x18\x05 \x03(\t\x12\x16\n\x0eretention_days\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x08 \x01(\t\x12\x18\n\x10storage_endpoint\x18\t \x01(\t\"\xf2\x01\n>ManagedInstancesDatabasesSchemasTablesColumnsSensitivityLabels\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10information_type\x18\x03 \x01(\t\x12\x1b\n\x13information_type_id\x18\x04 \x01(\t\x12\x10\n\x08label_id\x18\x05 \x01(\t\x12\x12\n\nlabel_name\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\"\x9a\x01\n9ManagedInstancesDatabasesBackupShortTermRetentionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0eretention_days\x18\x03 \x01(\x05\"\xe6\x01\n8ManagedInstancesDatabasesBackupLongTermRetentionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11monthly_retention\x18\x03 \x01(\t\x12\x18\n\x10weekly_retention\x18\x04 \x01(\t\x12\x14\n\x0cweek_of_year\x18\x05 \x01(\x05\x12\x18\n\x10yearly_retention\x18\x06 \x01(\t\"\xd5\x0b\n\x19ManagedInstancesDatabases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1d\n\x15\x61uto_complete_restore\x18\x04 \x01(\x08\x12\x19\n\x11\x63\x61talog_collation\x18\x05 \x01(\t\x12\x11\n\tcollation\x18\x06 \x01(\t\x12\x13\n\x0b\x63reate_mode\x18\x07 \x01(\t\x12\x18\n\x10last_backup_name\x18\x08 \x01(\t\x12.\n&long_term_retention_backup_resource_id\x18\t \x01(\t\x12\x1f\n\x17recoverable_database_id\x18\n \x01(\t\x12&\n\x1erestorable_dropped_database_id\x18\x0b \x01(\t\x12\x1d\n\x15restore_point_in_time\x18\x0c \x01(\t\x12\x1a\n\x12source_database_id\x18\r \x01(\t\x12#\n\x1bstorage_container_sas_token\x18\x0e \x01(\t\x12\x1d\n\x15storage_container_uri\x18\x0f \x01(\t\x12\x63\n\x04tags\x18\x10 \x03(\x0b\x32U.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabases.TagsEntry\x12\xb5\x01\n@managed_instances_databases_backup_short_term_retention_policies\x18\x11 \x03(\x0b\x32k.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabasesBackupShortTermRetentionPolicies\x12\x9d\x01\n3managed_instances_databases_security_alert_policies\x18\x12 \x03(\x0b\x32`.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabasesSecurityAlertPolicies\x12\xa5\x01\n7managed_instances_databases_transparent_data_encryption\x18\x13 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabasesTransparentDataEncryption\x12\xa2\x01\n5managed_instances_databases_vulnerability_assessments\x18\x14 \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabasesVulnerabilityAssessments\x12\xb3\x01\n?managed_instances_databases_backup_long_term_retention_policies\x18\x15 \x03(\x0b\x32j.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDatabasesBackupLongTermRetentionPolicies\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x99\x01\n*ManagedInstancesAzureADOnlyAuthentications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x03 \x01(\x08\"\xb2\x01\n\x1eManagedInstancesAdministrators\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x64ministrator_type\x18\x03 \x01(\t\x12\r\n\x05login\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\"\x95\x14\n\x10ManagedInstances\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12T\n\x08identity\x18\x02 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_managedinstances.ResourceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13\x61\x64ministrator_login\x18\x05 \x01(\t\x12$\n\x1c\x61\x64ministrator_login_password\x18\x06 \x01(\t\x12n\n\x0e\x61\x64ministrators\x18\x07 \x01(\x0b\x32V.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstanceExternalAdministrator\x12\x11\n\tcollation\x18\x08 \x01(\t\x12\x18\n\x10\x64ns_zone_partner\x18\t \x01(\t\x12\x18\n\x10instance_pool_id\x18\n \x01(\t\x12\x0e\n\x06key_id\x18\x0b \x01(\t\x12\x14\n\x0clicense_type\x18\x0c \x01(\t\x12$\n\x1cmaintenance_configuration_id\x18\r \x01(\t\x12$\n\x1cmanaged_instance_create_mode\x18\x0e \x01(\t\x12\x1b\n\x13minimal_tls_version\x18\x0f \x01(\t\x12)\n!primary_user_assigned_identity_id\x18\x10 \x01(\t\x12\x16\n\x0eproxy_override\x18\x11 \x01(\t\x12$\n\x1cpublic_data_endpoint_enabled\x18\x12 \x01(\x08\x12+\n#requested_backup_storage_redundancy\x18\x13 \x01(\t\x12\x1d\n\x15restore_point_in_time\x18\x14 \x01(\t\x12]\n\x11service_principal\x18\x15 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_managedinstances.ServicePrincipal\x12\"\n\x1asource_managed_instance_id\x18\x16 \x01(\t\x12\x1a\n\x12storage_size_in_gb\x18\x17 \x01(\x05\x12\x11\n\tsubnet_id\x18\x18 \x01(\t\x12\x13\n\x0btimezone_id\x18\x19 \x01(\t\x12\x0f\n\x07v_cores\x18\x1a \x01(\x05\x12\x16\n\x0ezone_redundant\x18\x1b \x01(\x08\x12\x42\n\x03sku\x18\x1c \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_sql_managedinstances.Sku\x12Z\n\x04tags\x18\x1d \x03(\x0b\x32L.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstances.TagsEntry\x12\x9a\x01\n1managed_instances_distributed_availability_groups\x18\x1e \x03(\x0b\x32_.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesDistributedAvailabilityGroups\x12z\n managed_instances_administrators\x18\x1f \x03(\x0b\x32P.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesAdministrators\x12\x95\x01\n/managed_instances_azure_ad_only_authentications\x18  \x03(\x0b\x32\\.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesAzureADOnlyAuthentications\x12\x85\x01\n&managed_instances_encryption_protector\x18! \x03(\x0b\x32U.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesEncryptionProtector\x12\x66\n\x16managed_instances_keys\x18\" \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesKeys\x12\x94\x01\n.managed_instances_private_endpoint_connections\x18# \x03(\x0b\x32\\.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesPrivateEndpointConnections\x12\x8f\x01\n+managed_instances_vulnerability_assessments\x18$ \x03(\x0b\x32Z.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesVulnerabilityAssessments\x12\x8a\x01\n)managed_instances_security_alert_policies\x18% \x03(\x0b\x32W.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesSecurityAlertPolicies\x12\x8e\x01\n+managed_instances_server_trust_certificates\x18& \x03(\x0b\x32Y.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesServerTrustCertificates\x12o\n\x1bmanaged_instances_sql_agent\x18\' \x03(\x0b\x32J.oak9.tython.azure.microsoft_sql_managedinstances.ManagedInstancesSqlAgent\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\t\" \n\x10ServicePrincipal\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xaf\x01\n$ManagedInstanceExternalAdministrator\x12\x1a\n\x12\x61\x64ministrator_type\x18\x01 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x02 \x01(\x08\x12\r\n\x05login\x18\x03 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\"\xe2\x01\n\x10ResourceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x80\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32^.oak9.tython.azure.microsoft_sql_managedinstances.ResourceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_sql_managedinstances_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MANAGEDINSTANCESDATABASES_TAGSENTRY._options = None
  _MANAGEDINSTANCESDATABASES_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDINSTANCES_TAGSENTRY._options = None
  _MANAGEDINSTANCES_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SQL_MANAGEDINSTANCES._serialized_start=124
  _MICROSOFT_SQL_MANAGEDINSTANCES._serialized_end=270
  _MANAGEDINSTANCESVULNERABILITYASSESSMENTS._serialized_start=273
  _MANAGEDINSTANCESVULNERABILITYASSESSMENTS._serialized_end=613
  _MANAGEDINSTANCESSQLAGENT._serialized_start=615
  _MANAGEDINSTANCESSQLAGENT._serialized_end=727
  _MANAGEDINSTANCESSERVERTRUSTCERTIFICATES._serialized_start=730
  _MANAGEDINSTANCESSERVERTRUSTCERTIFICATES._serialized_end=863
  _MANAGEDINSTANCESSECURITYALERTPOLICIES._serialized_start=866
  _MANAGEDINSTANCESSECURITYALERTPOLICIES._serialized_end=1157
  _MANAGEDINSTANCESRESTORABLEDROPPEDDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_start=1160
  _MANAGEDINSTANCESRESTORABLEDROPPEDDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_end=1331
  _MANAGEDINSTANCESPRIVATEENDPOINTCONNECTIONS._serialized_start=1334
  _MANAGEDINSTANCESPRIVATEENDPOINTCONNECTIONS._serialized_end=1721
  _MANAGEDINSTANCEPRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_start=1723
  _MANAGEDINSTANCEPRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_end=1818
  _MANAGEDINSTANCEPRIVATEENDPOINTPROPERTY._serialized_start=1820
  _MANAGEDINSTANCEPRIVATEENDPOINTPROPERTY._serialized_end=1872
  _MANAGEDINSTANCESKEYS._serialized_start=1875
  _MANAGEDINSTANCESKEYS._serialized_end=2006
  _MANAGEDINSTANCESENCRYPTIONPROTECTOR._serialized_start=2009
  _MANAGEDINSTANCESENCRYPTIONPROTECTOR._serialized_end=2198
  _MANAGEDINSTANCESDISTRIBUTEDAVAILABILITYGROUPS._serialized_start=2201
  _MANAGEDINSTANCESDISTRIBUTEDAVAILABILITYGROUPS._serialized_end=2479
  _MANAGEDINSTANCESDATABASESVULNERABILITYASSESSMENTSRULESBASELINES._serialized_start=2482
  _MANAGEDINSTANCESDATABASESVULNERABILITYASSESSMENTSRULESBASELINES._serialized_end=2743
  _DATABASEVULNERABILITYASSESSMENTRULEBASELINEITEM._serialized_start=2745
  _DATABASEVULNERABILITYASSESSMENTRULEBASELINEITEM._serialized_end=2810
  _MANAGEDINSTANCESDATABASESVULNERABILITYASSESSMENTS._serialized_start=2813
  _MANAGEDINSTANCESDATABASESVULNERABILITYASSESSMENTS._serialized_end=3162
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_start=3164
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_end=3284
  _MANAGEDINSTANCESDATABASESTRANSPARENTDATAENCRYPTION._serialized_start=3287
  _MANAGEDINSTANCESDATABASESTRANSPARENTDATAENCRYPTION._serialized_end=3425
  _MANAGEDINSTANCESDATABASESSECURITYALERTPOLICIES._serialized_start=3428
  _MANAGEDINSTANCESDATABASESSECURITYALERTPOLICIES._serialized_end=3728
  _MANAGEDINSTANCESDATABASESSCHEMASTABLESCOLUMNSSENSITIVITYLABELS._serialized_start=3731
  _MANAGEDINSTANCESDATABASESSCHEMASTABLESCOLUMNSSENSITIVITYLABELS._serialized_end=3973
  _MANAGEDINSTANCESDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_start=3976
  _MANAGEDINSTANCESDATABASESBACKUPSHORTTERMRETENTIONPOLICIES._serialized_end=4130
  _MANAGEDINSTANCESDATABASESBACKUPLONGTERMRETENTIONPOLICIES._serialized_start=4133
  _MANAGEDINSTANCESDATABASESBACKUPLONGTERMRETENTIONPOLICIES._serialized_end=4363
  _MANAGEDINSTANCESDATABASES._serialized_start=4366
  _MANAGEDINSTANCESDATABASES._serialized_end=5859
  _MANAGEDINSTANCESDATABASES_TAGSENTRY._serialized_start=5816
  _MANAGEDINSTANCESDATABASES_TAGSENTRY._serialized_end=5859
  _MANAGEDINSTANCESAZUREADONLYAUTHENTICATIONS._serialized_start=5862
  _MANAGEDINSTANCESAZUREADONLYAUTHENTICATIONS._serialized_end=6015
  _MANAGEDINSTANCESADMINISTRATORS._serialized_start=6018
  _MANAGEDINSTANCESADMINISTRATORS._serialized_end=6196
  _MANAGEDINSTANCES._serialized_start=6199
  _MANAGEDINSTANCES._serialized_end=8780
  _MANAGEDINSTANCES_TAGSENTRY._serialized_start=5816
  _MANAGEDINSTANCES_TAGSENTRY._serialized_end=5859
  _SKU._serialized_start=8782
  _SKU._serialized_end=8863
  _SERVICEPRINCIPAL._serialized_start=8865
  _SERVICEPRINCIPAL._serialized_end=8897
  _MANAGEDINSTANCEEXTERNALADMINISTRATOR._serialized_start=8900
  _MANAGEDINSTANCEEXTERNALADMINISTRATOR._serialized_end=9075
  _RESOURCEIDENTITY._serialized_start=9078
  _RESOURCEIDENTITY._serialized_end=9304
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=9243
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=9304
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeImageXGuestOsFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ComputeImageXGuestOsFeatures = ComputeImageXGuestOsFeatures

@typing_extensions.final
class ComputeImageXRawDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_TYPE_FIELD_NUMBER: builtins.int
    SHA1_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    container_type: builtins.str
    sha1: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        container_type: builtins.str = ...,
        sha1: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_type", b"container_type", "sha1", b"sha1", "source", b"source"]) -> None: ...

global___ComputeImageXRawDisk = ComputeImageXRawDisk

@typing_extensions.final
class ComputeImageXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeImageXTimeouts = ComputeImageXTimeouts

@typing_extensions.final
class ComputeImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SOURCE_DISK_FIELD_NUMBER: builtins.int
    SOURCE_IMAGE_FIELD_NUMBER: builtins.int
    SOURCE_SNAPSHOT_FIELD_NUMBER: builtins.int
    GUEST_OS_FEATURES_FIELD_NUMBER: builtins.int
    RAW_DISK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    archive_size_bytes: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    disk_size_gb: builtins.float
    family: builtins.str
    id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    source_disk: builtins.str
    source_image: builtins.str
    source_snapshot: builtins.str
    @property
    def guest_os_features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeImageXGuestOsFeatures]: ...
    @property
    def raw_disk(self) -> global___ComputeImageXRawDisk: ...
    @property
    def timeouts(self) -> global___ComputeImageXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        archive_size_bytes: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        family: builtins.str = ...,
        id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        source_disk: builtins.str = ...,
        source_image: builtins.str = ...,
        source_snapshot: builtins.str = ...,
        guest_os_features: collections.abc.Iterable[global___ComputeImageXGuestOsFeatures] | None = ...,
        raw_disk: global___ComputeImageXRawDisk | None = ...,
        timeouts: global___ComputeImageXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["raw_disk", b"raw_disk", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_size_bytes", b"archive_size_bytes", "creation_timestamp", b"creation_timestamp", "description", b"description", "disk_size_gb", b"disk_size_gb", "family", b"family", "guest_os_features", b"guest_os_features", "id", b"id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "licenses", b"licenses", "name", b"name", "project", b"project", "raw_disk", b"raw_disk", "resource_info", b"resource_info", "self_link", b"self_link", "source_disk", b"source_disk", "source_image", b"source_image", "source_snapshot", b"source_snapshot", "timeouts", b"timeouts"]) -> None: ...

global___ComputeImage = ComputeImage

@typing_extensions.final
class ComputeImageIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeImageIamBindingXCondition = ComputeImageIamBindingXCondition

@typing_extensions.final
class ComputeImageIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    image: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeImageIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        image: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeImageIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "image", b"image", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeImageIamBinding = ComputeImageIamBinding

@typing_extensions.final
class ComputeImageIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeImageIamMemberXCondition = ComputeImageIamMemberXCondition

@typing_extensions.final
class ComputeImageIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    image: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeImageIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        image: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeImageIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "image", b"image", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeImageIamMember = ComputeImageIamMember

@typing_extensions.final
class ComputeImageIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    image: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        image: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "image", b"image", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___ComputeImageIamPolicy = ComputeImageIamPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds_dbinstance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_rds_dbinstance.proto\x12\x1eoak9.tython.aws.rds_dbinstance\x1a\x13shared/shared.proto\"{\n\x18\x44\x42InstanceDBInstanceRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"r\n\x1a\x44\x42InstanceProcessorFeature\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xf2\r\n\nDBInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61llocated_storage\x18\x02 \x01(\t\x12#\n\x1b\x61llow_major_version_upgrade\x18\x03 \x01(\x08\x12R\n\x10\x61ssociated_roles\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbinstance.DBInstanceDBInstanceRole\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x05 \x01(\x08\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x07 \x01(\x05\x12!\n\x19\x63\x61_certificate_identifier\x18\x08 \x01(\t\x12\x1a\n\x12\x63haracter_set_name\x18\t \x01(\t\x12\x1d\n\x15\x63opy_tags_to_snapshot\x18\n \x01(\x08\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x0b \x01(\t\x12\x19\n\x11\x64\x62_instance_class\x18\x0c \x01(\t\x12\x1e\n\x16\x64\x62_instance_identifier\x18\r \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0e \x01(\t\x12\x1f\n\x17\x64\x62_parameter_group_name\x18\x0f \x01(\t\x12\x1a\n\x12\x64\x62_security_groups\x18\x10 \x03(\t\x12\x1e\n\x16\x64\x62_snapshot_identifier\x18\x11 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x12 \x01(\t\x12 \n\x18\x64\x65lete_automated_backups\x18\x13 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x12\x0e\n\x06\x64omain\x18\x15 \x01(\t\x12\x1c\n\x14\x64omain_iam_role_name\x18\x16 \x01(\t\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x17 \x03(\t\x12*\n\"enable_iam_database_authentication\x18\x18 \x01(\x08\x12#\n\x1b\x65nable_performance_insights\x18\x19 \x01(\x08\x12\x0e\n\x06\x65ngine\x18\x1a \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x1b \x01(\t\x12\x0c\n\x04iops\x18\x1c \x01(\x05\x12\x12\n\nkms_key_id\x18\x1d \x01(\t\x12\x15\n\rlicense_model\x18\x1e \x01(\t\x12\x1c\n\x14master_user_password\x18\x1f \x01(\t\x12\x17\n\x0fmaster_username\x18  \x01(\t\x12\x1d\n\x15max_allocated_storage\x18! \x01(\x05\x12\x1b\n\x13monitoring_interval\x18\" \x01(\x05\x12\x1b\n\x13monitoring_role_arn\x18# \x01(\t\x12\x10\n\x08multi_az\x18$ \x01(\x08\x12\x19\n\x11option_group_name\x18% \x01(\t\x12\'\n\x1fperformance_insights_kms_key_id\x18& \x01(\t\x12-\n%performance_insights_retention_period\x18\' \x01(\x05\x12\x0c\n\x04port\x18( \x01(\t\x12\x1f\n\x17preferred_backup_window\x18) \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18* \x01(\t\x12V\n\x12processor_features\x18+ \x03(\x0b\x32:.oak9.tython.aws.rds_dbinstance.DBInstanceProcessorFeature\x12\x16\n\x0epromotion_tier\x18, \x01(\x05\x12\x1b\n\x13publicly_accessible\x18- \x01(\x08\x12%\n\x1dsource_db_instance_identifier\x18. \x01(\t\x12\x15\n\rsource_region\x18/ \x01(\t\x12\x19\n\x11storage_encrypted\x18\x30 \x01(\x08\x12\x14\n\x0cstorage_type\x18\x31 \x01(\t\x12\x42\n\x04tags\x18\x32 \x03(\x0b\x32\x34.oak9.tython.aws.rds_dbinstance.DBInstance.TagsEntry\x12\x10\n\x08timezone\x18\x33 \x01(\t\x12&\n\x1euse_default_processor_features\x18\x34 \x01(\x08\x12\x1b\n\x13vpc_security_groups\x18\x35 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xae\x05\n\x0eRDS_DBInstance\x12?\n\x0b\x64\x62_instance\x18\x01 \x01(\x0b\x32*.oak9.tython.aws.rds_dbinstance.DBInstance\x12L\n\x12\x64\x62_parameter_group\x18\x02 \x01(\x0b\x32\x30.oak9.tython.aws.rds_dbinstance.DBParameterGroup\x12\x39\n\x08\x64\x62_proxy\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.rds_dbinstance.DBProxy\x12Q\n\x15\x64\x62_proxy_target_group\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.rds_dbinstance.DBProxyTargetGroup\x12J\n\x11\x64\x62_security_group\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.rds_dbinstance.DBSecurityGroup\x12Y\n\x19\x64\x62_security_group_ingress\x18\x06 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbinstance.DBSecurityGroupIngress\x12\x46\n\x0f\x64\x62_subnet_group\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.rds_dbinstance.DBSubnetGroup\x12M\n\x12\x65vent_subscription\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.rds_dbinstance.EventSubscription\x12\x41\n\x0coption_group\x18\t \x01(\x0b\x32+.oak9.tython.aws.rds_dbinstance.OptionGroup\"\xf0\x02\n\x10\x44\x42ParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12T\n\nparameters\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.rds_dbinstance.DBParameterGroup.ParametersEntry\x12H\n\x04tags\x18\x05 \x03(\x0b\x32:.oak9.tython.aws.rds_dbinstance.DBParameterGroup.TagsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfe\x02\n\x07\x44\x42Proxy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x15\n\rdebug_logging\x18\x03 \x01(\x08\x12\x15\n\rengine_family\x18\x04 \x01(\t\x12\x1b\n\x13idle_client_timeout\x18\x05 \x01(\x05\x12\x13\n\x0brequire_tls\x18\x06 \x01(\x08\x12\x10\n\x08role_arn\x18\x07 \x01(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.rds_dbinstance.DBProxyTagFormat\x12\x1e\n\x16vpc_security_group_ids\x18\t \x03(\t\x12\x16\n\x0evpc_subnet_ids\x18\n \x03(\t\x12\x39\n\x04\x61uth\x18\x0b \x03(\x0b\x32+.oak9.tython.aws.rds_dbinstance.DBProxyAuth\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xc6\x02\n\x12\x44\x42ProxyTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdb_proxy_name\x18\x02 \x01(\t\x12\x19\n\x11target_group_name\x18\x03 \x01(\t\x12\x83\x01\n\"connection_pool_configuration_info\x18\x04 \x01(\x0b\x32W.oak9.tython.aws.rds_dbinstance.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x1f\n\x17\x64\x62_instance_identifiers\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x62_cluster_identifiers\x18\x06 \x03(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"\xcb\x02\n\x0f\x44\x42SecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x19\x64\x62_security_group_ingress\x18\x02 \x03(\x0b\x32\x36.oak9.tython.aws.rds_dbinstance.DBSecurityGroupIngress\x12\x13\n\x0b\x65_c2_vpc_id\x18\x03 \x01(\t\x12\x19\n\x11group_description\x18\x04 \x01(\t\x12G\n\x04tags\x18\x05 \x03(\x0b\x32\x39.oak9.tython.aws.rds_dbinstance.DBSecurityGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x64\x62_subnet_group_description\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x45\n\x04tags\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.rds_dbinstance.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x11\x45ventSubscription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10\x65vent_categories\x18\x03 \x03(\t\x12\x15\n\rsns_topic_arn\x18\x04 \x01(\t\x12\x12\n\nsource_ids\x18\x05 \x03(\t\x12\x13\n\x0bsource_type\x18\x06 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb6\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12Q\n\x0foption_settings\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.rds_dbinstance.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\t\"\xa9\x01\n\x0b\x44\x42ProxyAuth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"\xec\x02\n\x0bOptionGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ngine_name\x18\x02 \x01(\t\x12\x1c\n\x14major_engine_version\x18\x03 \x01(\t\x12]\n\x15option_configurations\x18\x04 \x03(\x0b\x32>.oak9.tython.aws.rds_dbinstance.OptionGroupOptionConfiguration\x12 \n\x18option_group_description\x18\x05 \x01(\t\x12\x43\n\x04tags\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.rds_dbinstance.OptionGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_dbinstance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBINSTANCE_TAGSENTRY._options = None
  _DBINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBPARAMETERGROUP_TAGSENTRY._options = None
  _DBPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSECURITYGROUP_TAGSENTRY._options = None
  _DBSECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _OPTIONGROUP_TAGSENTRY._options = None
  _OPTIONGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBINSTANCEDBINSTANCEROLE._serialized_start=85
  _DBINSTANCEDBINSTANCEROLE._serialized_end=208
  _DBINSTANCEPROCESSORFEATURE._serialized_start=210
  _DBINSTANCEPROCESSORFEATURE._serialized_end=324
  _DBINSTANCE._serialized_start=327
  _DBINSTANCE._serialized_end=2105
  _DBINSTANCE_TAGSENTRY._serialized_start=2062
  _DBINSTANCE_TAGSENTRY._serialized_end=2105
  _RDS_DBINSTANCE._serialized_start=2108
  _RDS_DBINSTANCE._serialized_end=2794
  _DBPARAMETERGROUP._serialized_start=2797
  _DBPARAMETERGROUP._serialized_end=3165
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_start=3071
  _DBPARAMETERGROUP_PARAMETERSENTRY._serialized_end=3120
  _DBPARAMETERGROUP_TAGSENTRY._serialized_start=2062
  _DBPARAMETERGROUP_TAGSENTRY._serialized_end=2105
  _DBPROXYTAGFORMAT._serialized_start=3167
  _DBPROXYTAGFORMAT._serialized_end=3270
  _DBPROXY._serialized_start=3273
  _DBPROXY._serialized_end=3655
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=3658
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=3931
  _DBPROXYTARGETGROUP._serialized_start=3934
  _DBPROXYTARGETGROUP._serialized_end=4260
  _DBSECURITYGROUPINGRESS._serialized_start=4263
  _DBSECURITYGROUPINGRESS._serialized_end=4465
  _DBSECURITYGROUP._serialized_start=4468
  _DBSECURITYGROUP._serialized_end=4799
  _DBSECURITYGROUP_TAGSENTRY._serialized_start=2062
  _DBSECURITYGROUP_TAGSENTRY._serialized_end=2105
  _DBSUBNETGROUP._serialized_start=4802
  _DBSUBNETGROUP._serialized_end=5077
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=2062
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=2105
  _EVENTSUBSCRIPTION._serialized_start=5080
  _EVENTSUBSCRIPTION._serialized_end=5263
  _OPTIONGROUPOPTIONSETTING._serialized_start=5265
  _OPTIONGROUPOPTIONSETTING._serialized_end=5377
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=5380
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=5690
  _DBPROXYAUTH._serialized_start=5693
  _DBPROXYAUTH._serialized_end=5862
  _OPTIONGROUP._serialized_start=5865
  _OPTIONGROUP._serialized_end=6229
  _OPTIONGROUP_TAGSENTRY._serialized_start=2062
  _OPTIONGROUP_TAGSENTRY._serialized_end=2105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_globalaccelerator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61ws/aws_globalaccelerator.proto\x12!oak9.tython.aws.globalaccelerator\x1a\x13shared/shared.proto\"\x89\x02\n\x0b\x41\x63\x63\x65lerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fip_address_type\x18\x03 \x01(\t\x12\x14\n\x0cip_addresses\x18\x04 \x03(\t\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x46\n\x04tags\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.globalaccelerator.Accelerator.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x01\n\x11GlobalAccelerator\x12\x43\n\x0b\x61\x63\x63\x65lerator\x18\x01 \x03(\x0b\x32..oak9.tython.aws.globalaccelerator.Accelerator\x12H\n\x0e\x65ndpoint_group\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.globalaccelerator.EndpointGroup\x12=\n\x08listener\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.globalaccelerator.Listener\"\xaa\x01\n\"EndpointGroupEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x65ndpoint_id\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\x12&\n\x1e\x63lient_ip_preservation_enabled\x18\x04 \x01(\x08\"\x9b\x03\n\rEndpointGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0clistener_arn\x18\x02 \x01(\t\x12\x1d\n\x15\x65ndpoint_group_region\x18\x03 \x01(\t\x12\x66\n\x17\x65ndpoint_configurations\x18\x04 \x03(\x0b\x32\x45.oak9.tython.aws.globalaccelerator.EndpointGroupEndpointConfiguration\x12\x1f\n\x17traffic_dial_percentage\x18\x05 \x01(\x01\x12\x19\n\x11health_check_port\x18\x06 \x01(\x05\x12\x1d\n\x15health_check_protocol\x18\x07 \x01(\t\x12\x19\n\x11health_check_path\x18\x08 \x01(\t\x12%\n\x1dhealth_check_interval_seconds\x18\t \x01(\x05\x12\x17\n\x0fthreshold_count\x18\n \x01(\x05\"p\n\x11ListenerPortRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfrom_port\x18\x02 \x01(\x05\x12\x0f\n\x07to_port\x18\x03 \x01(\x05\"\xd2\x01\n\x08Listener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x63\x63\x65lerator_arn\x18\x02 \x01(\t\x12I\n\x0bport_ranges\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.globalaccelerator.ListenerPortRange\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x17\n\x0f\x63lient_affinity\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_globalaccelerator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCELERATOR_TAGSENTRY._options = None
  _ACCELERATOR_TAGSENTRY._serialized_options = b'8\001'
  _ACCELERATOR._serialized_start=92
  _ACCELERATOR._serialized_end=357
  _ACCELERATOR_TAGSENTRY._serialized_start=314
  _ACCELERATOR_TAGSENTRY._serialized_end=357
  _GLOBALACCELERATOR._serialized_start=360
  _GLOBALACCELERATOR._serialized_end=585
  _ENDPOINTGROUPENDPOINTCONFIGURATION._serialized_start=588
  _ENDPOINTGROUPENDPOINTCONFIGURATION._serialized_end=758
  _ENDPOINTGROUP._serialized_start=761
  _ENDPOINTGROUP._serialized_end=1172
  _LISTENERPORTRANGE._serialized_start=1174
  _LISTENERPORTRANGE._serialized_end=1286
  _LISTENER._serialized_start=1289
  _LISTENER._serialized_end=1499
# @@protoc_insertion_point(module_scope)
